@@ -1,5 +1,5 @@
 <?php
-/* $Id: italian-iso-8859-15.inc.php 10538 2007-07-28 14:26:00Z lem9 $ */
+/* $Id: italian-iso-8859-15.inc.php 11121 2008-02-12 18:05:59Z lem9 $ */
 
 /**
  * translated by: Pietro Danesi <danone at users.sourceforge.net>  2002-03-29
@@ -55,7 +55,7 @@ $strAlterOrderBy = 'Altera tabella ordinata per';
 $strAnalyzeTable = 'Analizza tabella';
 $strAnd = 'e';
 $strAndThen = 'e quindi';
-$strAngularLinks = 'Men angolari';
+$strAngularLinks = 'Link angolari';
 $strAnIndex = 'Un indice  stato aggiunto in %s';
 $strAnyHost = 'Qualsiasi host';
 $strAny = 'Qualsiasi';
@@ -107,7 +107,7 @@ $strBzError = 'phpMyAdmin non  capace di comprimere il dump a causa dell\'estens
 $strBzip = '"compresso con bzip2"';
 
 $strCalendar = 'Calendario';
-$strCancel = 'Cancella';
+$strCancel = 'Annulla';
 $strCanNotLoadExportPlugins = 'Non posso caricare i plugins di esportazione. Controlla l\'installazione!';
 $strCanNotLoadImportPlugins = 'Non posso caricare i plugins di importazione, controlla la tua configurazione!';
 $strCannotLogin = 'Impossibile eseguire il login nel server MySQL';
@@ -214,11 +214,11 @@ $strDefragment = 'Deframmenta la tabella';
 $strDelayedInserts = 'Utilizza inserimenti ritardati';
 $strDeleteAndFlush = 'Cancella gli utenti e dopo ricarica i privilegi.';
 $strDeleteAndFlushDescr = 'Questa  la vita pi giusta, ma il caricamento dei privilegi pu durare qualche secondo.';
-$strDelete = 'Cancella';
 $strDeleted = 'La riga  stata cancellata';
 $strDeletedRows = 'Righe cancellate:';
+$strDelete = 'Elimina';
 $strDeleteNoUsersSelected = 'Nessun utente selezionato per la cancellazione!';
-$strDeleteRelation = 'Cancella relazione';
+$strDeleteRelation = 'Elimina relazione';
 $strDeleting = 'Cancellazione in corso di %s';
 $strDelimiter = 'Delimitatori';
 $strDelOld = 'La Pagina corrente contiene Riferimenti a Tabelle che non esistono pi. Volete cancellare questi Riferimenti?';
@@ -624,7 +624,7 @@ $strProfiling = 'Profiling';
 $strProtocolVersion = 'Versione protocollo';
 $strPutColNames = 'Mette i nomi delle colonne alla prima riga';
 
-$strQBEDel = 'Cancella';
+$strQBEDel = 'Elimina';
 $strQBEIns = 'Aggiungi';
 $strQBE = 'Query da esempio';
 $strQueryCache = 'Cache delle query';
@@ -894,6 +894,7 @@ $strStructureForView = 'Struttura per la vista';
 $strStructure = 'Struttura';
 $strSubmit = 'Invia';
 $strSuccess = 'La query  stata eseguita con successo';
+$strSuhosin = 'Sul server  in esecuzione Suhosin. Controlla la documentazione: %sdocumentation%s per possibili problemi.';
 $strSum = 'Totali';
 $strSwedish = 'Svedese';
 $strSwitchToDatabase = 'Passare al Database copiato';
