@@ -3,7 +3,7 @@
 /**
  *
  *
- * @version $Id: Config.class.php 10932 2007-11-20 13:17:00Z lem9 $
+ * @version $Id: Config.class.php 11218 2008-04-29 11:44:42Z lem9 $
  */
 
 /**
@@ -85,7 +85,7 @@ class PMA_Config
      */
     function checkSystem()
     {
-        $this->set('PMA_VERSION', '2.11.2.2');
+        $this->set('PMA_VERSION', '2.11.6');
         /**
          * @deprecated
          */
@@ -372,6 +372,8 @@ class PMA_Config
          * Parses the configuration file
          */
         $old_error_reporting = error_reporting(0);
+        // avoid "headers already sent" error when file contains a BOM
+        ob_start();
         if (function_exists('file_get_contents')) {
             $eval_result =
                 eval('?>' . trim(file_get_contents($this->getSource())));
@@ -379,6 +381,7 @@ class PMA_Config
             $eval_result =
                 eval('?>' . trim(implode("\n", file($this->getSource()))));
         }
+        ob_end_clean();
         error_reporting($old_error_reporting);
 
         if ($eval_result === false) {
@@ -542,9 +545,9 @@ class PMA_Config
      * or the theme changes
      * @return  int  Unix timestamp
      */
-    function getMtime()
+    function getThemeUniqueValue()
     {
-        return intval($_SESSION['PMA_Config']->get('fontsize')) + ($this->source_mtime + $this->default_source_mtime + $_SESSION['PMA_Theme']->mtime_info);
+        return intval($_SESSION['PMA_Config']->get('fontsize')) + ($this->source_mtime + $this->default_source_mtime + $_SESSION['PMA_Theme']->mtime_info + $_SESSION['PMA_Theme']->filesize_info);
     }
 
     /**
@@ -751,11 +754,16 @@ class PMA_Config
      */
     function checkUpload()
     {
-        $this->set('enable_upload', true);
-        if (strtolower(@ini_get('file_uploads')) == 'off'
-          || @ini_get('file_uploads') == 0) {
+        if (ini_get('file_uploads')) {
+            $this->set('enable_upload', true);
+            // if set "php_admin_value file_uploads Off" in httpd.conf
+            // ini_get() also returns the string "Off" in this case:
+            if ('off' == strtolower(ini_get('file_uploads'))) {
+                $this->set('enable_upload', false);
+            }
+         } else {
             $this->set('enable_upload', false);
-        }
+         }
     }
 
     /**
@@ -856,17 +864,18 @@ class PMA_Config
         if (empty($url)) {
             if (PMA_getenv('PATH_INFO')) {
                 $url = PMA_getenv('PATH_INFO');
+            // on IIS with PHP-CGI:
+            } elseif (PMA_getenv('SCRIPT_NAME')) {
+                $url = PMA_getenv('SCRIPT_NAME');
             } elseif (PMA_getenv('PHP_SELF')) {
                 // PHP_SELF in CGI often points to cgi executable, so use it
                 // as last choice
                 $url = PMA_getenv('PHP_SELF');
-            } elseif (PMA_getenv('SCRIPT_NAME')) {
-                $url = PMA_getenv('PHP_SELF');
             }
         }
 
         $parsed_url = @parse_url($_SERVER['REQUEST_URI']); // produces E_WARNING if it cannot get parsed, e.g. '/foobar:/'
-        if ($parsed_url === false) {
+        if ($parsed_url === false || empty($parsed_url['path'])) {
             $parsed_url = array('path' => $url);
         }
 
@@ -880,8 +889,9 @@ class PMA_Config
      */
     function enableBc()
     {
-        $GLOBALS['cfg']             =& $this->settings;
-        $GLOBALS['default_server']  =& $this->default_server;
+        $GLOBALS['cfg']             = $this->settings;
+        $GLOBALS['default_server']  = $this->default_server;
+        unset($this->default_server);
         $GLOBALS['collation_connection'] = $this->get('collation_connection');
         $GLOBALS['is_upload']       = $this->get('enable_upload');
         $GLOBALS['max_upload_size'] = $this->get('max_upload_size');
