@@ -2,7 +2,7 @@
 /* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  *
- * @version $Id: Table.class.php 10679 2007-09-27 16:56:09Z lem9 $
+ * @version $Id: Table.class.php 11172 2008-03-21 14:38:14Z lem9 $
  */
 
 /**
@@ -343,16 +343,22 @@ class PMA_Table {
 
         if (!empty($extra)) {
             $query .= ' ' . $extra;
-            // An auto_increment field must be use as a primary key
-            if ($extra == 'AUTO_INCREMENT' && isset($field_primary)) {
+            // Force an auto_increment field to be part of the primary key
+            // even if user did not tick the PK box; 
+            // but the PK could contain other columns so do not append
+            // a PRIMARY KEY clause, just add a member to $field_primary
+            if ($extra == 'AUTO_INCREMENT') {
                 $primary_cnt = count($field_primary);
-                for ($j = 0; $j < $primary_cnt && $field_primary[$j] != $index; $j++) {
-                    // void
+                $found_in_pk = false;
+                for ($j = 0; $j < $primary_cnt; $j++) {
+                    if ($field_primary[$j] == $index) {
+                        $found_in_pk = true;
+                        break;
+                    }
                 } // end for
-                if (isset($field_primary[$j]) && $field_primary[$j] == $index) {
-                    $query .= ' PRIMARY KEY';
-                    unset($field_primary[$j]);
-                } // end if
+                if (! $found_in_pk) {
+                    $field_primary[] = $index;
+                }
             } // end if (auto_increment)
         }
         if (PMA_MYSQL_INT_VERSION >= 40100 && !empty($comment)) {
@@ -599,9 +605,16 @@ class PMA_Table {
                 }
             }
             unset($analyzed_sql);
+            $server_sql_mode = PMA_DBI_fetch_value("SHOW VARIABLES LIKE 'sql_mode'", 0, 1);
+            if ('ANSI_QUOTES' == $server_sql_mode) {
+                $table_delimiter = 'quote_double';
+            } else {
+                $table_delimiter = 'quote_backtick';
+            }
+            unset($server_sql_mode);
 
             /* nijel: Find table name in query and replace it */
-            while ($parsed_sql[$i]['type'] != 'quote_backtick') {
+            while ($parsed_sql[$i]['type'] != $table_delimiter) {
                 $i++;
             }
 
@@ -617,7 +630,7 @@ class PMA_Table {
                 $last = $parsed_sql['len'] - 1;
                 $backquoted_source_db = PMA_backquote($source_db);
                 for (++$i; $i <= $last; $i++) {
-                            if ($parsed_sql[$i]['type'] == 'quote_backtick' && $parsed_sql[$i]['data'] == $backquoted_source_db) {
+                            if ($parsed_sql[$i]['type'] == $table_delimiter && $parsed_sql[$i]['data'] == $backquoted_source_db) {
                                 $parsed_sql[$i]['data'] = $target_for_view;
                     }
                 }
@@ -657,8 +670,8 @@ class PMA_Table {
                 $parsed_sql =  PMA_SQP_parse($GLOBALS['sql_constraints_query']);
                 $i = 0;
 
-                // find the first quote_backtick, it must be the source table name
-                while ($parsed_sql[$i]['type'] != 'quote_backtick') {
+                // find the first $table_delimiter, it must be the source table name
+                while ($parsed_sql[$i]['type'] != $table_delimiter) {
                     $i++;
                     // maybe someday we should guard against going over limit
                     //if ($i == $parsed_sql['len']) {
@@ -669,7 +682,7 @@ class PMA_Table {
                 // replace it by the target table name, no need to PMA_backquote()
                 $parsed_sql[$i]['data'] = $target;
 
-                // now we must remove all quote_backtick that follow a CONSTRAINT
+                // now we must remove all $table_delimiter that follow a CONSTRAINT
                 // keyword, because a constraint name must be unique in a db
 
                 $cnt = $parsed_sql['len'] - 1;
@@ -677,7 +690,7 @@ class PMA_Table {
                 for ($j = $i; $j < $cnt; $j++) {
                     if ($parsed_sql[$j]['type'] == 'alpha_reservedWord'
                       && strtoupper($parsed_sql[$j]['data']) == 'CONSTRAINT') {
-                        if ($parsed_sql[$j+1]['type'] == 'quote_backtick') {
+                        if ($parsed_sql[$j+1]['type'] == $table_delimiter) {
                             $parsed_sql[$j+1]['data'] = '';
                         }
                     }
