@@ -3,7 +3,7 @@
 /**
  * Misc functions used all over the scripts.
  *
- * @version $Id: common.lib.php 10870 2007-10-20 18:58:04Z lem9 $
+ * @version $Id: common.lib.php 11183 2008-04-02 17:19:59Z lem9 $
  */
 
 /**
@@ -410,7 +410,8 @@ function PMA_showHint($hint_message)
  * @uses    $GLOBALS['pmaThemeImage']
  * @uses    $GLOBALS['strEdit']
  * @uses    $GLOBALS['strMySQLSaid']
- * @uses    $cfg['PropertiesIconic']
+ * @uses    $GLOBALS['cfg']['PropertiesIconic'] 
+ * @uses    $GLOBALS['cfg']['MaxCharactersInDisplayedSQL'] 
  * @uses    PMA_backquote()
  * @uses    PMA_DBI_getError()
  * @uses    PMA_formatSql()
@@ -471,7 +472,11 @@ function PMA_mysqlDie($error_message = '', $the_query = '',
     } elseif (empty($the_query) || trim($the_query) == '') {
         $formatted_sql = '';
     } else {
-        $formatted_sql = PMA_formatSql(PMA_SQP_parse($the_query), $the_query);
+        if (strlen($the_query) > $GLOBALS['cfg']['MaxCharactersInDisplayedSQL']) {
+            $formatted_sql = substr($the_query, 0, $GLOBALS['cfg']['MaxCharactersInDisplayedSQL']) . '[...]';
+        } else {
+            $formatted_sql = PMA_formatSql(PMA_SQP_parse($the_query), $the_query);
+        }
     }
     // ---
     echo "\n" . '<!-- PMA-SQL-ERROR -->' . "\n";
@@ -572,7 +577,7 @@ function PMA_mysqlDie($error_message = '', $the_query = '',
  *
  * @access  private
  */
-function PMA_convert_using($string, $mode='unquoted')
+function PMA_convert_using($string, $mode='unquoted', $force_utf8 = false)
 {
     if ($mode == 'quoted') {
         $possible_quote = "'";
@@ -581,8 +586,14 @@ function PMA_convert_using($string, $mode='unquoted')
     }
 
     if (PMA_MYSQL_INT_VERSION >= 40100) {
-        list($conn_charset) = explode('_', $GLOBALS['collation_connection']);
-        $converted_string = "CONVERT(" . $possible_quote . $string . $possible_quote . " USING " . $conn_charset . ")";
+        if ($force_utf8) {
+            $charset = 'utf8';
+            $collate = ' COLLATE utf8_bin';
+        } else {
+            list($charset) = explode('_', $GLOBALS['collation_connection']);
+            $collate = '';
+        }
+        $converted_string = "CONVERT(" . $possible_quote . $string . $possible_quote . " USING " . $charset . ")" . $collate;
     } else {
         $converted_string = $possible_quote . $string . $possible_quote;
     }
@@ -868,6 +879,11 @@ function PMA_reloadNavigation()
 
     // Reloads the navigation frame via JavaScript if required
     if (isset($GLOBALS['reload']) && $GLOBALS['reload']) {
+        // one of the reasons for a reload is when a table is dropped
+        // in this case, get rid of the table limit offset, otherwise
+        // we have a problem when dropping a table on the last page
+        // and the offset becomes greater than the total number of tables
+        unset($_SESSION['userconf']['table_limit_offset']);
         echo "\n";
         $reload_url = './navigation.php?' . PMA_generate_common_url($GLOBALS['db'], '', '&');
         ?>
@@ -1208,6 +1224,25 @@ function PMA_showMessage($message, $sql_query = null)
 } // end of the 'PMA_showMessage()' function
 
 
+/**
+ * Verifies if current MySQL server supports profiling 
+ *
+ * @access  public
+ * @return  boolean whether profiling is supported 
+ *
+ * @author   Marc Delisle 
+ */
+function PMA_profilingSupported() {
+    // 5.0.37 has profiling but for example, 5.1.20 does not
+    // (avoid a trip to the server for MySQL before 5.0.37)
+    // and do not set a constant as we might be switching servers
+    if (defined('PMA_MYSQL_INT_VERSION') && PMA_MYSQL_INT_VERSION >= 50037 && PMA_DBI_fetch_value("SHOW VARIABLES LIKE 'profiling'")) {
+        return true;
+    } else {
+        return false;
+    }
+}
+
 /**
  * Displays a form with the Profiling checkbox 
  *
@@ -1217,12 +1252,10 @@ function PMA_showMessage($message, $sql_query = null)
  * @author   Marc Delisle 
  */
 function PMA_profilingCheckbox($sql_query) {
-    // 5.0.37 has profiling but for example, 5.1.20 does not
-    // (avoid doing a fetch_value for MySQL before 5.0.37)
-    if (PMA_MYSQL_INT_VERSION >= 50037 && PMA_DBI_fetch_value("SHOW VARIABLES LIKE 'profiling'")) {
+    if (PMA_profilingSupported()) {
         echo '<form action="sql.php" method="post">' . "\n";
         echo PMA_generate_common_hidden_inputs($GLOBALS['db'], $GLOBALS['table']);
-        echo '<input type="hidden" name="sql_query" value="' . $sql_query . '" />' . "\n";
+        echo '<input type="hidden" name="sql_query" value="' . htmlspecialchars($sql_query) . '" />' . "\n";
         echo '<input type="hidden" name="profiling_form" value="1" />' . "\n";
         echo '<input type="checkbox" name="profiling" id="profiling"' . (isset($_SESSION['profiling']) ? ' checked="checked"' : '') . ' onclick="this.form.submit();" /><label for="profiling">' . $GLOBALS['strProfiling'] . '</label>' . "\n";
         echo '<noscript><input type="submit" value="' . $GLOBALS['strGo'] . '" /></noscript>' . "\n";
@@ -2046,8 +2079,8 @@ function PMA_pageselector($url, $rows, $pageNow = 1, $nbTotalPage = 1,
     $showAll = 200, $sliceStart = 5, $sliceEnd = 5, $percent = 20,
     $range = 10, $prompt = '')
 {
-    $gotopage = $prompt 
-              . ' <select name="goToPage" onchange="goToUrl(this, \''
+    $gotopage = $prompt
+              . ' <select name="pos" onchange="goToUrl(this, \''
               . $url . '\');">' . "\n";
     if ($nbTotalPage < $showAll) {
         $pages = range(1, $nbTotalPage);
@@ -2111,24 +2144,25 @@ function PMA_pageselector($url, $rows, $pageNow = 1, $nbTotalPage = 1,
         $gotopage .= '                <option ' . $selected . ' value="' . (($i - 1) * $rows) . '">' . $i . '</option>' . "\n";
     }
 
-    $gotopage .= ' </select>';
+    $gotopage .= ' </select><noscript><input type="submit" value="' . $GLOBALS['strGo'] . '" /></noscript>';
+
 
     return $gotopage;
 } // end function
 
 
 /**
- * Generate navigation for a list 
+ * Generate navigation for a list
  *
- * @todo    use $pos from $_url_params 
+ * @todo    use $pos from $_url_params
  * @uses    $GLOBALS['strPageNumber']
  * @uses    range()
- * @param   integer     number of elements in the list 
- * @param   integer     current position in the list 
- * @param   array       url parameters 
- * @param   string      script name for form target 
- * @param   string      target frame 
- * @param   integer     maximum number of elements to display from the list 
+ * @param   integer     number of elements in the list
+ * @param   integer     current position in the list
+ * @param   array       url parameters
+ * @param   string      script name for form target
+ * @param   string      target frame
+ * @param   integer     maximum number of elements to display from the list
  *
  * @access  public
  */
@@ -2163,7 +2197,7 @@ function PMA_listNavigator($count, $pos, $_url_params, $script, $frame, $max_cou
                 . $caption2 . '</a>';
         }
 
-        echo '<form action="./' . $script . '" method="post">' . "\n";
+        echo "\n", '<form action="./', basename($script), '" method="post" target="', $frame, '">', "\n";
         echo PMA_generate_common_hidden_inputs($_url_params);
         echo PMA_pageselector(
             $script . PMA_generate_common_url($_url_params) . '&',
@@ -2185,7 +2219,7 @@ function PMA_listNavigator($count, $pos, $_url_params, $script, $frame, $max_cou
                 $title4   = '';
             } // end if... else...
             $_url_params['pos'] = $pos + $max_count;
-            echo '<a' . $title3 . ' href="' . $script 
+            echo '<a' . $title3 . ' href="' . $script
                 . PMA_generate_common_url($_url_params) . '" target="' . $frame . '">'
                 . $caption3 . '</a>';
             $_url_params['pos'] = floor($count / $max_count) * $max_count;
@@ -2276,4 +2310,51 @@ function PMA_externalBug($functionality, $component, $minimum_version, $bugref)
         echo PMA_showHint(sprintf($GLOBALS['strKnownExternalBug'], $functionality, 'http://bugs.mysql.com/' . $bugref));
     }
 }
+
+/**
+ * Converts a bit value to printable format;
+ * in MySQL a BIT field can be from 1 to 64 bits so we need this
+ * function because in PHP, decbin() supports only 32 bits
+ *
+ * @uses    ceil()
+ * @uses    decbin()
+ * @uses    ord()
+ * @uses    substr()
+ * @uses    sprintf()
+ * @param   numeric $value coming from a BIT field
+ * @param   integer $length 
+ * @return  string  the printable value 
+ */
+function PMA_printable_bit_value($value, $length) {
+    $printable = '';
+    for ($i = 0; $i < ceil($length / 8); $i++) {
+        $printable .= sprintf('%08d', decbin(ord(substr($value, $i, 1))));
+    }
+    $printable = substr($printable, -$length);
+    return $printable;
+}
+
+/**
+ * Extracts the true field type and length from a field type spec
+ *
+ * @uses    strpos()
+ * @uses    chop()
+ * @uses    substr()
+ * @param   string $fieldspec 
+ * @return  array associative array containing the type and length 
+ */
+function PMA_extract_type_length($fieldspec) {
+    $first_bracket_pos = strpos($fieldspec, '(');
+    if ($first_bracket_pos) {
+        $length = chop(substr($fieldspec, $first_bracket_pos + 1, (strpos($fieldspec, ')') - $first_bracket_pos - 1)));
+        $type = chop(substr($fieldspec, 0, $first_bracket_pos));
+    } else {
+        $type = $fieldspec;
+        $length = '';
+    }
+    return array(
+        'type' => $type,
+        'length' => $length
+    );
+}
 ?>
