@@ -1,9 +1,9 @@
 <?php
-/* $Id: mysqli.dbi.lib.php 9252 2006-08-03 12:58:46Z cybot_tm $ */
-// vim: expandtab sw=4 ts=4 sts=4:
-
+/* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * Interface to the improved MySQL extension (MySQLi)
+ *
+ * @version $Id: mysqli.dbi.lib.php 11189 2008-04-06 12:52:53Z lem9 $
  */
 
 // MySQL client API
@@ -87,7 +87,17 @@ function PMA_DBI_connect($user, $password, $is_controluser = false)
 
     mysqli_options($link, MYSQLI_OPT_LOCAL_INFILE, true);
 
-    $client_flags = $GLOBALS['cfg']['Server']['compress'] && defined('MYSQLI_CLIENT_COMPRESS') ? MYSQLI_CLIENT_COMPRESS : 0;
+    $client_flags = 0;
+
+    /* Optionally compress connection */
+    if ($GLOBALS['cfg']['Server']['compress'] && defined('MYSQLI_CLIENT_COMPRESS')) {
+        $client_flags |= MYSQLI_CLIENT_COMPRESS;
+    }
+
+    /* Optionally enable SSL */
+    if ($GLOBALS['cfg']['Server']['ssl'] && defined('MYSQLI_CLIENT_SSL')) {
+        $client_flags |= MYSQLI_CLIENT_SSL;
+    }
 
     $return_value = @mysqli_real_connect($link, $GLOBALS['cfg']['Server']['host'], $user, $password, false, $server_port, $server_socket, $client_flags);
 
@@ -97,6 +107,12 @@ function PMA_DBI_connect($user, $password, $is_controluser = false)
     }
 
     if ($return_value == false) {
+        if ($is_controluser) {
+            if (! defined('PMA_DBI_CONNECT_FAILED_CONTROLUSER')) {
+                define('PMA_DBI_CONNECT_FAILED_CONTROLUSER', true);
+            }
+            return false;
+        }
         PMA_auth_fails();
     } // end if
 
@@ -168,20 +184,7 @@ function PMA_DBI_try_query($query, $link = null, $options = 0)
     if (defined('PMA_MYSQL_INT_VERSION') && PMA_MYSQL_INT_VERSION < 40100) {
         $query = PMA_convert_charset($query);
     }
-    $result = mysqli_query($link, $query, $method);
-
-    if (mysqli_warning_count($link)) {
-        // TODO: check $method ?
-        $warning_result = mysqli_query($link, 'SHOW WARNINGS');
-        if ($warning_result) {
-            $warning_row = mysqli_fetch_row($warning_result);
-            $GLOBALS['warning'] = sprintf("%s (%d): %s", $warning_row[0], $warning_row[1], $warning_row[2]);
-        }
-    } else {
-        unset($GLOBALS['warning']);
-    }
-
-    return $result;
+    return mysqli_query($link, $query, $method);
 
     // From the PHP manual:
     // "note: returns true on success or false on failure. For SELECT,
@@ -323,15 +326,13 @@ function PMA_DBI_fetch_row($result)
  * @uses    mysqli_result
  * @uses    func_get_args()
  * @uses    is_object()
- * @uses    is_a()
  * @uses    mysqli_free_result()
  * @param   result  $result,...     one or more mysql result resources
  */
 function PMA_DBI_free_result()
 {
     foreach (func_get_args() as $result) {
-        if (is_object($result)
-          && is_a($result, 'mysqli_result')) {
+        if ($result instanceof mysqli_result) {
             mysqli_free_result($result);
         }
     }
@@ -363,7 +364,7 @@ function PMA_DBI_get_host_info($link = null)
  * @param   resource        $link   mysql link
  * @return  integer         version of the MySQL protocol used
  */
-function PMA_DBI_get_proto_info( $link = null )
+function PMA_DBI_get_proto_info($link = null)
 {
     if (null === $link) {
         if (isset($GLOBALS['userlink'])) {
@@ -405,7 +406,7 @@ function PMA_DBI_get_client_info()
  */
 function PMA_DBI_getError($link = null)
 {
-    unset($GLOBALS['errno']);
+    $GLOBALS['errno'] = 0;
 
     if (null === $link && isset($GLOBALS['userlink'])) {
         $link =& $GLOBALS['userlink'];
@@ -520,7 +521,7 @@ function PMA_DBI_affected_rows($link = null)
 /**
  * returns metainfo for fields in $result
  *
- * @TODO preserve orignal flags value
+ * @todo preserve orignal flags value
  * @uses    PMA_DBI_field_flags()
  * @uses    MYSQLI_TYPE_*
  * @uses    MYSQLI_MULTIPLE_KEY_FLAG
@@ -544,7 +545,7 @@ function PMA_DBI_get_fields_meta($result)
     $typeAr = array();
     $typeAr[MYSQLI_TYPE_DECIMAL]     = 'real';
     $typeAr[MYSQLI_TYPE_NEWDECIMAL]  = 'real';
-    $typeAr[MYSQLI_TYPE_BIT]         = 'bool';
+    $typeAr[MYSQLI_TYPE_BIT]         = 'int';
     $typeAr[MYSQLI_TYPE_TINY]        = 'int';
     $typeAr[MYSQLI_TYPE_SHORT]       = 'int';
     $typeAr[MYSQLI_TYPE_LONG]        = 'int';
@@ -573,6 +574,7 @@ function PMA_DBI_get_fields_meta($result)
     // https://sf.net/tracker/?func=detail&aid=1532111&group_id=23067&atid=377408
     //$typeAr[MYSQLI_TYPE_CHAR]        = 'string';
     $typeAr[MYSQLI_TYPE_GEOMETRY]    = 'unknown';
+    $typeAr[MYSQLI_TYPE_BIT]         = 'bit';
 
     $fields = mysqli_fetch_fields($result);
 
